#nvpl_fft-config.cmake
#
# Imported interface targets provided:
#  nvpl::fftw - fftw shared library target
#
# Output variables set:
#  * nvpl_fft_VERSION - Version of installed package
#  * nvpl_fft_INCLUDE_DIR - Location of nvpl_fft headers
#  * nvpl_fft_LIBRARY_DIR - Location of nvpl_fft libraries

set(nvpl_fft_VERSION "0.3.0")
# build: 2564


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was nvpl_fft-config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# Find header and lib directories via known header and lib names
set(_nvpl_fft_search_header_name nvpl_fftw.h)
set(_nvpl_fft_search_lib_name libnvpl_fftw.so)
get_filename_component(_nvpl_fft_search_prefix "${CMAKE_CURRENT_LIST_DIR}/../../" ABSOLUTE)

find_path(nvpl_fft_INCLUDE_DIR
          NAMES ${_nvpl_fft_search_header_name}
          PATHS ${_nvpl_fft_search_prefix}
          PATH_SUFFIXES
            ../include
            ../../include # Debian/Ubuntu aarch64
          NO_DEFAULT_PATH
          NO_CACHE) # Set cache variable after path normalization

find_path(nvpl_fft_LIBRARY_DIR
          NAMES ${_nvpl_fft_search_lib_name}
          PATHS ${_nvpl_fft_search_prefix}
          PATH_SUFFIXES lib lib64
          DOC "Location of  libraries"
          NO_DEFAULT_PATH)

# Check headers and library directories are found
if(NOT EXISTS "${nvpl_fft_INCLUDE_DIR}")
    message(FATAL_ERROR "Header directory containing file ${_nvpl_fft_search_header_name} was not found relative to ${CMAKE_CURRENT_LIST_DIR}!")
endif()
if(NOT EXISTS "${nvpl_fft_LIBRARY_DIR}")
    message(FATAL_ERROR "Library directory containing file ${_nvpl_fft_search_lib_name} was not found relative to ${CMAKE_CURRENT_LIST_DIR}!")
endif()

# Normalize nvpl_fft_INCLUDE_DIR and set cache variable
get_filename_component(nvpl_fft_INCLUDE_DIR "${nvpl_fft_INCLUDE_DIR}" ABSOLUTE)
set(nvpl_fft_INCLUDE_DIR ${nvpl_fft_INCLUDE_DIR} CACHE STRING "Location of  headers")

unset(_nvpl_fft_search_header_name)
unset(_nvpl_fft_search_lib_name)
unset(_nvpl_fft_search_prefix)

## Targets
if(NOT TARGET nvpl_fftw)
    include("${CMAKE_CURRENT_LIST_DIR}/nvpl_fft-targets.cmake")
    set_target_properties(nvpl_fftw PROPERTIES IMPORTED_GLOBAL 1)
endif()

if(NOT TARGET nvpl::fftw)
    add_library(nvpl::fftw ALIAS nvpl_fftw)
endif()

get_target_property(nvpl_fft_BUILD_TYPES nvpl_fftw IMPORTED_CONFIGURATIONS)

check_required_components(nvpl_fft)

if(NOT ${CMAKE_FIND_PACKAGE_NAME}_FIND_QUIETLY)
    message(STATUS "Found nvpl_fft: (Version:0.3.0
                    CMakePackageDir:${CMAKE_CURRENT_LIST_DIR}
                    IncludeDir:${nvpl_fft_INCLUDE_DIR}
                    LibraryDir:${nvpl_fft_LIBRARY_DIR})")
endif()
